@@ -28,6 +28,7 @@ WikiJS options:
   --wiki-git-branch=<wiki_branch>   The name of the branch that the wiki content should be loaded from. [default: main]
   --wiki-git-no-verify              Do not verify the ssl certificate when cloning the wikijs wiki.
   --wiki-navigation=<type>          The type of wiki navigation to confgigure, either 'TREE' or 'NONE'. [default: TREE]
+  --wiki-comments                   If commenting should be enabled in the wiki. [default: False]
 
 Docker options:
   -t --tag=<tag>                    The docker tag to use for the generated image. This should exclude the registry portion. [default: sci-oer/custom:latest]
@@ -66,7 +67,7 @@ import datetime
 import importlib.resources as pkg_resources
 
 try:
-    from git import Repo  # noqa: I900
+    from git import Repo, GitCommandError  # noqa: I900
 except:
     sys.exit("Can not run, `git` must be installed on the system.")
 
@@ -74,6 +75,7 @@ from .__version__ import __version__  # noqa: I900
 from .prompt import prompt, yesno, prompt_list
 
 SSH_KEY_FILE_ENV = "SSH_KEY_FILE"
+SSH_OPTIONS = "SSH_OPTIONS"
 
 # this is the api token that has been built into the base-resource container
 API_TOKEN = "eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJhcGkiOjEsImdycCI6MSwiaWF0IjoxNjQyOTcyMTk5LCJleHAiOjE3Mzc2NDQ5OTksImF1ZCI6InVybjp3aWtpLmpzIiwiaXNzIjoidXJuOndpa2kuanMifQ.xkvgFfpYw2OgB0Z306YzVjOmuYzrKgt_fZLXetA0ThoAgHNH1imou2YCh-JBXSBCILbuYvfWMSwOhf5jAMKT7O1QJNMhs5W0Ls7Cj5tdlOgg-ufMZaLH8X2UQzkD-1o3Dhpv_7hs9G8xt7qlqCz_-DwroOGUGPaGW6wrtUfylUyYh86V9eJveRJqzZXiGFY3n6Z3DuzIVZtz-DoCHMaDceSG024BFOD-oexMCnAxTpk5OalEhwucaYHS2sNCLpmwiEGHSswpiaMq9-JQasVJtQ_fZ9yU_ZZLBlc0AJs1mOENDTI6OBZ3IS709byqxEwSPnWaF_Tk7fcGnCYk-3gixA"  # noqa E501
@@ -270,8 +272,16 @@ def clone_repo(repo, name, dir, keep_git=False, **kwargs):
 
     git_ssh_cmd = ""
     if repo.isSSH():
-        git_ssh_cmd = f'ssh {"-o StrictHostKeyChecking=no " if not repo.verify_host else " "}-i {repo.auth.ssh_file}'
-    Repo.clone_from(repo.uri, folder, env=dict(GIT_SSH_COMMAND=git_ssh_cmd))
+        sshOptions = os.environ.get(SSH_OPTIONS, "")
+        keyFile = f"-i {repo.auth.ssh_file}" if repo.auth.ssh_file else ""
+        git_ssh_cmd = f'ssh {sshOptions} {"-o StrictHostKeyChecking=no " if not repo.verify_host else " "}{keyFile}'
+
+    try:
+        Repo.clone_from(repo.uri, folder, env=dict(GIT_SSH_COMMAND=git_ssh_cmd))
+    except GitCommandError as e:
+        _LOGGER.error("Failed to clone the git repository")
+        _LOGGER.error(e)
+        return
 
     if not keep_git:
         # make sure that the git directory is removed before it gets loaded into the image
@@ -425,6 +435,19 @@ def import_wiki_repo(host, **kwargs):
     _LOGGER.warning("Done importing wiki content")
 
 
+def set_wiki_comments(host, enabled, **kwargs):
+
+    query = """mutation Site ($comments: Boolean!){
+        site {
+            updateConfig (featurePageComments: $comments ) {
+                responseResult { succeeded, errorCode, slug, message }
+            }
+        }
+    }"""
+
+    api_call(host, query, variables={"comments": enabled}, **kwargs)
+
+
 def set_wiki_title(host, title, **kwargs):
 
     if title is None:
@@ -643,7 +666,7 @@ def run(opts, **kwargs):
         )
         sys.exit("Incompatible arguments")
 
-    sshKeyFile = load_ssh_key(os.path.expanduser(opts["key_file"]))
+    sshKeyFile = load_ssh_key(os.path.expanduser(opts["key_file"] or ""))
     if sshKeyFile != "":
         sshKeyFile = os.path.realpath(sshKeyFile)
 
@@ -758,6 +781,7 @@ def run(opts, **kwargs):
 
     set_wiki_title(host, opts["wiki_title"], port=port)
     set_wiki_navigation_mode(host, opts["wiki_navigation"], port=port)
+    set_wiki_comments(host, opts["wiki_comments"], port=port)
     dissable_api(host, port=port)
 
     stop_container(container)
